% simuate ShiftCP data
clear all;
Fs=512;  % Sample rate
time_points=linspace(0,1,Fs)';
%% Generate non-negative trial strenghts
FACT{1}=rand(10,4);

%% Generate Drift component
FACT{2}(:,1)=time_points-mean(time_points);
% Generate 24 Hz component
FACT{2}(:,2)=cos(2*pi*24*time_points*Fs);
% Generate 12 Hz component
FACT{2}(:,3)=cos(2*pi*12*time_points*Fs);
% Generate 150 Hz component
FACT{2}(:,4)=cos(2*pi*50*time_points*Fs);
% Normalize generated time components
FACT{2}=FACT{2}./(ones(size(FACT{2},1),1)*sqrt(sum(FACT{2}.^2)));

%% Generate random topography
FACT{3}=randn(10,4);

%% Generate delays between -10 and 10 samples
T=ceil(20*rand(10,4)-10);

%% Reconstruct the data and add noise
Rec = reconstructShiftCP(FACT,T); % Generate Data
X=Rec+0.01*randn(size(Rec));      % Add noise

% Set algorithm parameters
opts.maxiter=250;
opts.constr=[1 0 0];
opts.SNR=0; % In general it may be better to set the SNR much lower, for instance opts.SNR=-10 
opts.Sample_rate=Fs;
opts.ARD=true;   
opts.InitRun=3;
%opts.TauW=zeros(10,2);
%% Run the algorithm
[FACT_est,T_est,nLogP,varexpl,Lambda] = ShiftCP(X,10,opts);

%% plot the results
figure;
noc_est=size(FACT_est{1},2);
for d=1:noc_est
    subplot(noc_est,3,(d-1)*3+1);
    plot(FACT_est{1}(:,d).*exp(-1i*2*pi*T_est(:,d)/size(X,2)),'.');
    axis tight;
    ylabel(['component ' num2str(d)],'FontWeight','bold');

    subplot(noc_est,3,(d-1)*3+2);
    plot(FACT_est{2}(:,d));
    axis tight;
    ylabel('Mode 2 Scores');
    xlabel('time points');

    subplot(noc_est,3,(d-1)*3+3);
    bar(FACT_est{3}(:,d));        
end